Package: Unicode
Version: 17.0.0-1
Encoding: UTF-8
Title: Unicode Data and Utilities
Authors@R: person("Kurt", "Hornik", role = c("aut", "cre"),
                  email = "Kurt.Hornik@R-project.org",
		  comment = c(ORCID = "0000-0003-4198-9911"))
Description: Data from Unicode 17.0.0 and related utilities.
Depends: R (>= 3.5.0)
Imports: utils
License: GPL-2
NeedsCompilation: no
Packaged: 2026-03-28 07:19:25 UTC; hornik
Author: Kurt Hornik [aut, cre] (ORCID: <https://orcid.org/0000-0003-4198-9911>)
Maintainer: Kurt Hornik <Kurt.Hornik@R-project.org>
Repository: CRAN
Date/Publication: 2026-03-28 07:26:35 UTC
Built: R 4.6.0; ; 2026-04-26 13:03:41 UTC; unix
