Written by Radovan Garabík <garabik @ kassiopeia.juls.savba.sk>.
For new versions, look at http://kassiopeia.juls.savba.sk/~garabik/software/unicode/

-------------------

paracode exploits the full power of the Unicode standard to convert the
text into visually similar stream of glyphs, while using completely
different codepoints. It is an excellent didactic tool demonstrating the
principles and advanced use of the Unicode standard. paracode is a
command line tool working as a filter, reading standard input in UTF-8
encoding and writing to standard output.

Use optional -t switch to select what tables to use.

Special name 'all' selects all the tables.

Note that selecting 'other', 'cyrillic_plus' and 'cherokee' tables (and
'all') makes use of rather esoteric characters, and not all fonts
contain them.

Special table 'mirror' uses quite different character substitution,
is not selected automatically with 'all' and does not work well
with anything except plain ascii alphabetical characters.

Example:

paracode -t cyrillic+greek+cherokee

paracode -t cherokee  <input >output

paracode -r -t mirror  <input >output


Possible tables are:

cyrillic

cyrillic_plus

greek

other

cherokee

all

