\name{u_named_sequences}
\alias{u_named_sequences}
\title{Unicode Named Sequences}
\description{
  Unicode named sequences.
}
\usage{
u_named_sequences()
}
\value{
  A data frame with elements \code{Name} and \code{Sequence} giving the
  names and the corresponding Unicode character sequences.
}
